@@ -226,30 +226,43 @@ function getCpuLoad($detailed = false) {
  * @return array Connection statistics for ports 80 and 443
  */
 function getConnectionCount($detailed = false) {
+    // Get unique client connections from HAProxy container
+    // This counts unique IP addresses connected to ports 80 and 443
+    $output = @shell_exec('docker exec haproxy-manager netstat -plan 2>/dev/null | grep -E "(:443|:80)" | awk -F " " \'{print $5}\' | awk -F ":" \'{print $1}\' | grep -v "0.0.0.0" | grep -v "::" | sort -u | wc -l');
+
+    $uniqueClients = 0;
+    if ($output !== null && trim($output) !== '') {
+        $uniqueClients = intval(trim($output));
+    }
+
+    // Get total connection count for detailed mode
+    $totalConnections = 0;
     $connections80 = 0;
     $connections443 = 0;
 
-    // Get established connections on port 80
-    $output80 = @shell_exec('ss -tn state established "( sport = :80 or dport = :80 )" 2>/dev/null | tail -n +2 | wc -l');
-    if ($output80 !== null) {
-        $connections80 = intval(trim($output80));
+    if ($detailed) {
+        // Count connections on port 80
+        $output80 = @shell_exec('docker exec haproxy-manager netstat -plan 2>/dev/null | grep -E ":80 " | wc -l');
+        if ($output80 !== null && trim($output80) !== '') {
+            $connections80 = intval(trim($output80));
+        }
+
+        // Count connections on port 443
+        $output443 = @shell_exec('docker exec haproxy-manager netstat -plan 2>/dev/null | grep -E ":443 " | wc -l');
+        if ($output443 !== null && trim($output443) !== '') {
+            $connections443 = intval(trim($output443));
+        }
+
+        $totalConnections = $connections80 + $connections443;
     }
 
-    // Get established connections on port 443
-    $output443 = @shell_exec('ss -tn state established "( sport = :443 or dport = :443 )" 2>/dev/null | tail -n +2 | wc -l');
-    if ($output443 !== null) {
-        $connections443 = intval(trim($output443));
-    }
-
-    $totalConnections = $connections80 + $connections443;
-
-    // Determine status based on total connections
-    if ($totalConnections < 100) {
-        $status = 'healthy';
-    } elseif ($totalConnections < 500) {
-        $status = 'warning';
-    } else {
+    // Determine status based on unique client connections
+    // Thresholds are for unique clients, not total connections
+    $status = 'healthy';
+    if ($uniqueClients >= 200) {
         $status = 'critical';
+    } elseif ($uniqueClients >= 100) {
+        $status = 'warning';
     }
 
     // Return only status by default, detailed metrics only if requested
@@ -259,6 +272,7 @@ function getConnectionCount($detailed = false) {
 
     return [
         'status' => $status,
+        'unique_clients' => $uniqueClients,
         'total_connections' => $totalConnections,
         'connections' => [
             'port_80' => $connections80,
